import config from "config";
import client from "lib/client";
import { getRandomInt } from "lib/utils";
import {
    kofiContent,
    supportContent,
    discadiaContent,
    disboardContent,
} from "./support.components.ts";
import type {
    CacheType,
    Interaction,
    ChatInputCommandInteraction,
} from "discord.js";
import { Commands, type CommandsType } from "commands/index.ts";

export class SupportService {
    async handleInteraction(interaction: Interaction<CacheType>) {
        if (interaction.isChatInputCommand()) {
            await this.handleChatInputCommand(interaction);
            return;
        }
    }

    async handleChatInputCommand(
        interaction: ChatInputCommandInteraction<CacheType>,
    ) {
        const commandName = interaction.commandName as CommandsType;
        switch (commandName) {
            case Commands.Enum.support:
                await this.supportCommand(interaction);
                return;
            case Commands.Enum.kofi:
                await this.kofiCommand(interaction);
                return;
            case Commands.Enum.disboard:
                await this.disboardCommand(interaction);
                return;
            case Commands.Enum.discadia:
                await this.discadiaCommand(interaction);
                return;
            default:
                break;
        }
    }
    async supportCommand(interaction: ChatInputCommandInteraction<CacheType>) {
        console.log("supportCommand");
        try {
            await interaction.reply({
                embeds: [supportContent],
                ephemeral: true,
            });
        } catch (error) {
            console.error("error while sending supportCommand msg:", error);
        }
    }

    async kofiCommand(interaction: ChatInputCommandInteraction<CacheType>) {
        console.log("kofiCommand");
        try {
            await interaction.reply({
                embeds: [kofiContent],
                ephemeral: true,
            });
        } catch (error) {
            console.error("error while sending kofiCommand msg:", error);
        }
    }

    async disboardCommand(interaction: ChatInputCommandInteraction<CacheType>) {
        console.log("disboardCommand");
        try {
            await interaction.reply({
                embeds: [disboardContent],
                ephemeral: true,
            });
        } catch (error) {
            console.error("error while sending disboardCommand msg:", error);
        }
    }

    async discadiaCommand(interaction: ChatInputCommandInteraction<CacheType>) {
        console.log("discadiaCommand");
        try {
            await interaction.reply({
                embeds: [discadiaContent],
                ephemeral: true,
            });
        } catch (error) {
            console.error("error while sending discadiaCommand msg:", error);
        }
    }
}
